Changelog — CEMENTO 0.8.6 documentation

Skip to main content
`Ctrl`+`K`

# Changelog

All notable changes to this project will be documented in this file.

The format is based on Keep a Changelog, and this project adheres to Semantic Versioning.

## [Guide]

- Added for new features.

- Changed for changes in existing functionality.

- Deprecated for soon-to-be removed features.

- Removed for now removed features.

- Fixed for any bug fixes.

- Security in case of vulnerabilities.

[Unreleased] section for tracking changes prior to binning to versions.

[X.X.X] - YYYY-MM-YY for version-date header

## [0.8.6] - 2025-07-24

### Added

- error check option on CLI

- term content in diagram error message

- defaults folder file contents to search terms

- feature to remove redundant statements about default namespace terms

- ability to define object properties

- support for multipage inputs

- feature to replace default object-property assignment to custom properties to swap with definitions if available

### Changed

- domain-range `.ttl` output to single element if only one

- to check errors by default

## [0.8.5] - 2025-07-23

### Added

- package documentation on github pages

- parse containers function

- googe site verification

- site logo and icon attribution

- sitemap

- reference ontology retrieval

- term types for all predicates

- restored error check feature on diagram, including error classes

### Changed

- hand-made XSD reference to XSD namespace inside `rdflib`

- no unique literals option to store true flag, setting no unique literals as the default behavior

- `file_path` argument in `conver_drawio_ttl` function to `input_path`

### Removed

- hand-made XSD reference

- do not check option

- not literal IDs

### Fixed

- exact match functionality not outputting all desired properties (label and SKOS exact match)

- non-bunny-eared data type string output

- prefixes not being imported from file

## [0.8.4] - 2025-07-20

NOTE: The changes listed here are a catch-all between this version and all prior releases. We haven’t kept a good changelog until today, so we apologize for the broad statements to keep this document section brief.

### Added

- application CLI

- support for converting directly to `.ttl` files from draw.io and vice versa

- support for literals and literal annotations (language and datatype)

- term matching via reference ontologies

- ability to add reference ontologies

- unique literal ID generation option

- support for annotation types

- classes-only option for drawing layouts

- ability to write prefixes

- tree-splitting for dealing with multiple inheritance

- stratified term category (includes definitions, annotations, etc.) for prioritizing in the layout

- match suppression with star keys

- alias support with parenthetic notation

- README instructions on CLI and scripting for new package implementation

### Changed

- programmming paradigm, from an clunky OOP-based approach to a hybrid functional approach

- File structure, adopting file conventions in functional programming

- all prior functionality implementations except those expressly mentioned in the remove section

- choosing more general category of terms to draw in the tree layout (stratified) versus just rank terms (subclass and type)

- shape definitions from native classes to dataclasses

- rendering shapes directly from dataclasses instead of through manual prop generation

- computing arrow directions dynamically based on shape angle instead of static case-based matching

- example scripts

### Removed

- All functions built under the OOP-based software

- shape-extent-based area diagram reading

- circle-based (organic) layouts

- straight-arrow and curve template files

- error detection in diagram reads

- defer-layout option